Index: pkg/watcher/lib/src/utils.dart |
diff --git a/pkg/watcher/lib/src/utils.dart b/pkg/watcher/lib/src/utils.dart |
index 319835ec944f3c955db24a0006e8f9e60cb4c54b..3d00c084314ad4cfcfbb0b290f795ef56d3d3769 100644 |
--- a/pkg/watcher/lib/src/utils.dart |
+++ b/pkg/watcher/lib/src/utils.dart |
@@ -6,9 +6,10 @@ library watcher.utils; |
import 'dart:io'; |
/// Returns `true` if [error] is a [DirectoryException] for a missing directory. |
bool isDirectoryNotFoundException(error) { |
- if (error is! DirectoryException) return false; |
+ if (error is! FileSystemException) return false; |
// See dartbug.com/12461 and tests/standalone/io/directory_error_test.dart. |
var notFoundCode = Platform.operatingSystem == "windows" ? 3 : 2; |
@@ -6,9 +6,10 @@ library watcher.utils; |
import 'dart:io'; |
-/// Returns `true` if [error] is a [DirectoryException] for a missing directory. |
+/// Returns `true` if [error] is a [FileSystemException] for a missing |
+/// directory. |
bool isDirectoryNotFoundException(error) { |